## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(dpi = 72)
knitr::opts_chunk$set(cache=FALSE)

## ---- fig.width=3, echo = FALSE, fig.align="center",hide=TRUE, message=FALSE,warning=FALSE----
knitr::include_graphics("Moonlight2_pipeline.gif")

## ---- eval = FALSE------------------------------------------------------------
#  if (!require("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("Moonlight2R")

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("devtools")
#  library(devtools)

## ---- eval = FALSE------------------------------------------------------------
#  devtools::install_github(repo = "ELELAB/Moonlight2R")

## ---- eval = FALSE------------------------------------------------------------
#  if (!require("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("BiocStyle")

## ---- eval = FALSE------------------------------------------------------------
#  devtools::install_github(repo = "ELELAB/Moonlight2R", build_vignettes = TRUE)

## ---- eval = FALSE------------------------------------------------------------
#  vignette( "Moonlight2R", package="Moonlight2R")

## ---- eval = TRUE-------------------------------------------------------------
library(Moonlight2R)
library(magrittr)
library(dplyr)

## ---- eval = TRUE-------------------------------------------------------------
data(DEGsmatrix)
data(dataFilt)
data(dataMAF)
data(GEO_TCGAtab)
data(LOC_transcription)
data(LOC_translation)
data(LOC_protein)
data(Oncogenic_mediators_mutation_summary)
data(DEG_Mutations_Annotations)

## ---- eval = TRUE, echo = TRUE------------------------------------------------
knitr::kable(GEO_TCGAtab, digits = 2,
       caption = "Table with GEO data set matched to one
       of the 18 given TCGA cancer types ",
       row.names = TRUE)

## ---- eval = TRUE, echo = TRUE, results='hide', warning = FALSE, message = FALSE----
dataFilt_GEO <- getDataGEO(GEOobject = "GSE20347", platform = "GPL571")

## ---- eval = TRUE, echo = TRUE, results='hide', warning = FALSE, message = FALSE----
dataFilt_GEO <- getDataGEO(TCGAtumor = "ESCA")

## ---- eval = TRUE, echo = TRUE, results='hide'--------------------------------
data(DEGsmatrix)
data(DiseaseList)
data(EAGenes)
dataFEA <- FEA(DEGsmatrix = DEGsmatrix)

## ---- eval = TRUE, echo = TRUE, message=FALSE, results='hide', warning=FALSE----
plotFEA(dataFEA = dataFEA, additionalFilename = "_exampleVignette", height = 10, width = 20)

## ---- fig.width=3, echo = FALSE, fig.align="center",hide=TRUE, message=FALSE,warning=FALSE----
knitr::include_graphics("FEAplot.gif")

## ---- eval = TRUE-------------------------------------------------------------
data(DEGsmatrix)
data(dataFilt)
dataGRN <- GRN(DEGsmatrix = DEGsmatrix, TFs = sample(rownames(DEGsmatrix), 100), normCounts = dataFilt,
	               nGenesPerm = 5, kNearest = 3, nBoot = 5, DiffGenes = TRUE)

## ---- eval = TRUE, echo = TRUE, results='hide'--------------------------------
data(dataGRN)
data(DEGsmatrix)
data(DiseaseList)
data(EAGenes)

dataFEA <- FEA(DEGsmatrix = DEGsmatrix)

BPselected <- dataFEA$Diseases.or.Functions.Annotation[1:5]
dataURA <- URA(dataGRN = dataGRN,
               DEGsmatrix = DEGsmatrix,
               BPname = BPselected, 
               nCores=1)

## ---- eval = TRUE-------------------------------------------------------------
data(dataURA)
data(tabGrowBlock)
data(knownDriverGenes)
dataPRA <- PRA(dataURA = dataURA,
               BPname = c("apoptosis","proliferation of cells"),
               thres.role = 0)

## ---- eval = FALSE------------------------------------------------------------
#  data(dataPRA)
#  data(dataMAF)
#  data(DEGsmatrix)
#  data(LOC_transcription)
#  data(LOC_translation)
#  data(LOC_protein)
#  data(NCG)
#  data(EncodePromoters)
#  dataDMA <- DMA(dataMAF = dataMAF,
#                 dataDEGs = DEGsmatrix,
#                 dataPRA = dataPRA,
#                 results_folder = "DMAresults",
#                 coding_file = "css_coding.vcf.gz",
#                 noncoding_file = "css_noncoding.vcf.gz")

## ---- eval = TRUE-------------------------------------------------------------
data(dataDMA)
genes_query <- Reduce(c, dataDMA)
dataGLS <- GLS(genes = genes_query, 
	       query_string = "AND cancer AND driver",
	       max_records = 20)
head(dataGLS)

## -----------------------------------------------------------------------------
knitr::kable(LOC_transcription)

## -----------------------------------------------------------------------------
knitr::kable(LOC_translation)

## -----------------------------------------------------------------------------
knitr::kable(LOC_protein)

## ---- eval = TRUE, echo = TRUE, results='hide', warning = FALSE, message = FALSE----
data(knownDriverGenes)
data(dataGRN)
plotNetworkHive(dataGRN, knownDriverGenes, 0.55)

## ---- eval = TRUE, warning = FALSE, message = FALSE, include=TRUE-------------
data(dataDMA)
data(DEG_Mutations_Annotations)
data(Oncogenic_mediators_mutation_summary)
plotDMA(DEG_Mutations_Annotations, 
        Oncogenic_mediators_mutation_summary, 
        type = 'complete', additionalFilename = "")

## ---- fig.width=3, fig.height=4, echo = FALSE, fig.align="center",hide=TRUE, message=FALSE,warning=FALSE----
knitr::include_graphics("heatmap_complete.gif")

## ---- eval = TRUE, echo = TRUE, results='hide', warning = FALSE, message = FALSE----
data(DEG_Mutations_Annotations)
data(Oncogenic_mediators_mutation_summary)
data(dataURA_plot)
plotMoonlight(DEG_Mutations_Annotations,
        Oncogenic_mediators_mutation_summary, 
        dataURA_plot, gene_type = "drivers", n = 50)

## ---- fig.width=3, echo = FALSE, fig.align="center",hide=TRUE, message=FALSE,warning=FALSE----
knitr::include_graphics("moonlight_heatmap.gif")

## ----eval = TRUE,echo=TRUE,message=FALSE,warning=FALSE, results='hide'--------
data(DEGsmatrix)
data(dataFilt)
data(DiseaseList)
data(EAGenes)
data(tabGrowBlock)
data(knownDriverGenes)

dataFEA <- FEA(DEGsmatrix = DEGsmatrix)

dataGRN <- GRN(TFs = sample(rownames(DEGsmatrix), 100), 
               DEGsmatrix = DEGsmatrix,
               DiffGenes = TRUE,
               normCounts = dataFilt,
               nGenesPerm = 5,
               nBoot = 5,
	       kNearest = 3)

dataURA <- URA(dataGRN = dataGRN, 
              DEGsmatrix = DEGsmatrix, 
              BPname = c("apoptosis",
                         "proliferation of cells"))

dataDual <- PRA(dataURA = dataURA, 
               BPname = c("apoptosis",
                          "proliferation of cells"),
               thres.role = 0)

oncogenic_mediators <- list("TSG"=names(dataDual$TSG), "OCG"=names(dataDual$OCG))


## ---- eval = TRUE,message=FALSE,warning=FALSE, results='hide'-----------------
data(dataURA) 
plotURA(dataURA = dataURA, additionalFilename = "_exampleVignette")

## ---- fig.width=3, echo = FALSE, fig.align="center",hide=TRUE, message=FALSE,warning=FALSE----
knitr::include_graphics("URAplot.gif")

## ----eval = FALSE,echo=TRUE,message=FALSE,warning=FALSE-----------------------
#  data(dataFilt)
#  data(DEGsmatrix)
#  data(dataMAF)
#  data(DiseaseList)
#  data(EAGenes)
#  data(tabGrowBlock)
#  data(knownDriverGenes)
#  data(LOC_transcription)
#  data(LOC_translation)
#  data(LOC_protein)
#  data(NCG)
#  data(EncodePromoters)
#  
#  listMoonlight <- moonlight(dataDEGs = DEGsmatrix,
#                             dataFilt = dataFilt,
#                             nTF = 100,
#                             DiffGenes = TRUE,
#  			   nGenesPerm = 5,
#                             nBoot = 5,
#                             BPname = c("apoptosis","proliferation of cells"),
#                             dataMAF = dataMAF,
#                             path_cscape_coding = "css_coding.vcf.gz",
#                             path_cscape_noncoding = "css_noncoding.vcf.gz")
#  save(listMoonlight, file = paste0("listMoonlight_ncancer4.Rdata"))
#  
#  

## ---- eval = TRUE, echo = TRUE, results='hide', warning = FALSE, message = FALSE----
data(listMoonlight)
plotCircos(listMoonlight = listMoonlight, additionalFilename = "_ncancer5")

## ---- fig.width=3, echo = FALSE, fig.align="center",hide=TRUE, message=FALSE,warning=FALSE----
knitr::include_graphics("circos_ocg_tsg_ncancer5.gif")

## ----eval = FALSE,echo=TRUE,message=FALSE,warning=FALSE-----------------------
#  
#  data(DEGsmatrix)
#  data(dataFilt)
#  data(dataMAF)
#  data(DiseaseList)
#  data(EAGenes)
#  data(tabGrowBlock)
#  data(knownDriverGenes)
#  data(LOC_transcription)
#  data(LOC_translation)
#  data(LOC_protein)
#  data(NCG)
#  data(EncodePromoters)
#  
#  # Perform gene regulatory network analysis
#  dataGRN <- GRN(TFs = rownames(DEGsmatrix),
#  	       DEGsmatrix = DEGsmatrix,
#  	       DiffGenes = TRUE,
#                 normCounts = dataFilt,
#                 nGenesPerm = 5,
#                 kNearest = 3,
#                 nBoot = 5)
#  
#  # Perform upstream regulatory analysis
#  # As example, we use apoptosis and proliferation of cells as the biological processes
#  dataURA <- URA(dataGRN = dataGRN,
#                 DEGsmatrix = DEGsmatrix,
#                 BPname = c("apoptosis",
#                            "proliferation of cells"),
#                 nCores = 1)
#  
#  # Perform pattern recognition analysis
#  dataPRA <- PRA(dataURA = dataURA,
#                 BPname = c("apoptosis",
#                            "proliferation of cells"),
#                 thres.role = 0)
#  
#  # Perform driver mutation analysis
#  dataDMA <- DMA(dataMAF = dataMAF,
#                 dataDEGs = DEGsmatrix,
#                 dataPRA = dataPRA,
#                 results_folder = "DMAresults",
#                 coding_file = "css_coding.vcf.gz",
#                 noncoding_file = "css_noncoding.vcf.gz")
#  

## ---- eval = TRUE-------------------------------------------------------------
data(Oncogenic_mediators_mutation_summary)
data(DEG_Mutations_Annotations)

# Extract oncogenic mediators that contain at least one driver mutation
# These are the driver genes
knitr::kable(Oncogenic_mediators_mutation_summary %>%
  filter(!is.na(CScape_Driver)))

# Extract mutation annotations of the predicted driver genes
driver_mut <- DEG_Mutations_Annotations %>% 
  filter(!is.na(Moonlight_Oncogenic_Mediator), 
         CScape_Mut_Class == "Driver")

# Extract driver genes with a predicted effect on the transcriptional level
transcription_mut <- Oncogenic_mediators_mutation_summary %>%
  filter(!is.na(CScape_Driver)) %>%
  filter(Transcription_mut_sum > 0)

# Extract mutation annotations of predicted driver genes that have a driver mutation
# in its promoter region with a potential effect on the transcriptional level 
promoters <- DEG_Mutations_Annotations %>% 
  filter(!is.na(Moonlight_Oncogenic_Mediator), 
         CScape_Mut_Class == "Driver",
         Potential_Effect_on_Transcription == 1,
         Annotation == 'Promoter')

## ----sessionInfo--------------------------------------------------------------
sessionInfo()

